@@ -4,7 +4,7 @@ use utf8; # encoding="utf-8"
 use warnings;
 use strict;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Acme::CPANAuthors::Register (
 	ABALAMA   => 'Lepenkov Sergey',
@@ -129,7 +129,6 @@ use Acme::CPANAuthors::Register (
 	YKAR      => 'Yuri Karaban',
 	YKOSTYLEV => 'Yuri Kostylev',
 	YURAN     => 'Nevinitsin Yury',
-	ZAG       => 'Zahatski Aliaksandr',
 	ZMIJ      => 'Sergei A. Fedorov',
 	ZOFFIX    => 'Zoffix Znet',
 );
@@ -162,8 +161,6 @@ See documentation for L<Acme::CPANAuthors> for more details.
 This class provides a hash of Russian CPAN authors' PAUSE ID and name to
 the C<Acme::CPANAuthors> module.
 
-Now B<125> Russian CPAN authors.
-
 =head1 MAINTENANCE
 
 If you are a Russian CPAN author not listed here, please send us your ID/name
@@ -172,23 +169,145 @@ via email or RT so we can always keep this module up to date.
 And if you aren't a Russian CPAN author listed here, please send us your ID/name
 via email or RT and we will remove your name.
 
-The script for fetch cpan authors you can see in the distributive I<examples/cpan-author.pl>.
+=head1 CONTAINED AUTHORS
+
+Now B<125> Russian CPAN authors:
+
+    ABALAMA   => 'Lepenkov Sergey',
+    ABEL      => 'Anton Belousov',
+    AKHOBOV   => 'Alexey Khobov',
+    AKIMOV    => 'Akimov Alexey',
+    AKR       => 'Alexey Kravchuk',
+    ALEXEYT   => 'Alexey Toptygin',
+    ALGDR     => 'Aleksandr Guidrevitch',
+    AMALTSEV  => 'Andrew Maltsev',
+    ANDY      => 'Andrew Shitov',
+    APLA      => 'Иван Бахчеев',
+    ARTO      => 'Artur Penttinen',
+    ASVBR     => 'Alexey Sharafutdinov',
+    ATOURBIN  => 'Alexey Tourbin',
+    AVP       => 'Alexey V. Presnyakov',
+    BASHLOV   => 'Dmitry Bashlov',
+    BEROV     => 'Красимир Беров',
+    BOSU      => 'Boris Sukholitko',
+    BUTILW    => 'Ilya Butakov',
+    CATONE    => 'Denis Pokataev',
+    CLEONTY   => 'Леонтий Чудинов',
+    CYBER     => 'Ivan M Nanev',
+    DAVINCHI  => 'Pavel Boldin',
+    DEEMON    => 'Dmitry Dorofeev',
+    DESPAIR   => 'Walery Studennikov',
+    DMITRI    => 'Dmitri Tikhonov',
+    DMITRY    => 'Dmitry Nikolayev',
+    DMITRYSOL => 'Dmitri Sologoubenko',
+    DMOW      => 'Dmitry Ovsyanko',
+    DPETROV   => 'Denis Petrov',
+    DSAMZA    => 'Dmitry Sagaev',
+    DZHARIY   => 'Дмитрий Жарий',
+    EGORSH    => 'Egor Shipovalov',
+    EJS       => 'Eugen Sobchenko',
+    FEDOROV   => 'Dmitry Fedorov',
+    GARIEV    => 'Igor Gariev',
+    GDSL      => 'Sergey Skvortsov',
+    GLORYBOX  => 'Sergey Sinkovskiy',
+    GOSHA     => 'Okunev Igor',
+    GRAYKOT   => 'Sergey Kotenko',
+    GRIAN     => 'Анатолий Гришаев',
+    GRISHACE  => 'Gregory Belenky',
+    GRUBER    => 'Anton Berezin',
+    GUGU      => 'Андрей Костенко',
+    ICHE      => 'Ilya Chelpanov',
+    ICHUDOV   => 'Igor Chudov',
+    IFROL     => 'Иван Фролков',
+    IGORM     => 'Igor Myroshnichenko',
+    INEULANDE => 'Ivan Neulander',
+    ISTERIN   => 'Ilya Sterin',
+    KAPPA     => 'Алексей Капранов',
+    KARASIK   => 'Dmitry Karasik',
+    KES       => 'Eugen Konkov',
+    KEU       => 'Dmitry V. Kolvakh',
+    KIRILLM   => 'Кирилл Мязин',
+    KLIMKIN   => 'Alexey Klimkin',
+    KOTEROV   => 'Dmitry Koterov',
+    KPV       => 'Pavel V. Kaygorodov',
+    KVENTIN   => 'Константин Матюхин',
+    LEO       => 'Черепанов Леонид',
+    LESV      => 'Suhanov Vadim',
+    LEXUS     => 'Usanov Alexey',
+    LIOL      => 'Lobanov Igor',
+    LOGVINON  => 'Nikolay Logvinov',
+    MAKAROW   => 'Andrew V. Makarow',
+    MAXICO    => 'Maxim Kashliak',
+    MBASOV    => 'Михаил В. Басов',
+    MIT       => 'Dmitriy Dontsov',
+    MONS      => 'Mons Anderson',
+    MPG       => 'Maxim  Grigoriev',
+    NICKOLA   => 'Nickolay Kovalev',
+    NIKIP     => 'Nikolay Pelov',
+    NIKOLAY   => 'Nikolay Bachiyski',
+    NRG       => 'Odintsov Pavel',
+    OLEGSHER  => 'Oleg Sher',
+    OLEKO     => 'Oleg Kobyakovskiy',
+    OMEGA     => 'Десислав Каменов/Desislav Kamenov',
+    PANOLEX   => 'Олександр Панчук',
+    PLCGI     => 'Alex',
+    PLISCO    => 'Igor Plisco',
+    PRO       => 'Oleg Alexeenkov',
+    PSMIRNOV  => 'Pavel Smirnov',
+    QUEVLAR   => 'Igor Sanchez-Puls',
+    RADKOV    => 'Alexey Radkov',
+    RHIZO     => 'Dmitry Karabanov',
+    RIIKI     => 'Oleg Prokopyev',
+    ROWAA     => 'Олег &quot;Rowaa[SR13]&quot; В. Волков',
+    RUDENKO   => 'Alexei Rudenko',
+    RUSAKOV   => 'Sergey Rusakov',
+    RUZ       => 'Ruslan U. Zakirov',
+    SAFRONOV  => 'Vladislav A. Safronov',
+    SASHA     => 'Alex Protasenko',
+    SAVA      => 'Сава Чанков',
+    SERG      => 'Sergei Golubchik',
+    SERGEY    => 'Sergey Gribov',
+    SERGEYCHE => 'Sergey Chernyshev',
+    SHARIFULN => 'Анатолий Шарифулин',
+    SKOLYCHEV => 'Sergey V. Kolychev',
+    SNEMAROV  => 'Sergei A. Nemarov',
+    SPECTRUM  => 'Черненко Эдуард Павлович',
+    STELLAR   => 'Andrei V. Shetuhin',
+    SWAJ      => 'Alexey Semenoff',
+    SWINED    => 'Alexey Alexandrov',
+    SYBER     => 'Олег Пронин',
+    SYP       => 'Станислав Пусеп',
+    TOLIKL    => 'Anatoly K. Lasareff',
+    TOYVO     => 'Anton Tayanovskyy',
+    TTOD      => 'Тодор Тодоров',
+    USTIANSKY => 'Vadim O. Ustiansky',
+    VADIM     => 'Vadim Ponomarenko',
+    VADIML    => 'Vadim Likhota (Вадим Лихота)',
+    VADIMT    => 'Vadim Trochinsky',
+    VANY      => 'Ivan B. Serezhkin',
+    VICTORI   => 'Victor Igumnov',
+    VIY       => 'Igor Yu. Vlasenko',
+    VKON      => 'Vadim Konovalov',
+    VLADB     => 'Vladimir Bogdanov',
+    VOVKASM   => 'Vladimir Timofeev',
+    VTI       => 'Вячеслав Тихановский',
+    XFIRE     => 'Ilya Obshadko',
+    YKAR      => 'Yuri Karaban',
+    YKOSTYLEV => 'Yuri Kostylev',
+    YURAN     => 'Nevinitsin Yury',
+    ZMIJ      => 'Sergei A. Fedorov',
+    ZOFFIX    => 'Zoffix Znet'
 
 =head1 SEE ALSO
 
 L<Acme::CPANAuthors> L<http://search.cpan.org/search?query=Acme%3A%3ACPANAuthors&mode=all>
 
-=head1 CONTAINED AUTHORS
-
-    ZOFFIX      => 'Zoffix Znet',
-    SHARIFULN   => 'Anatoly Sharifulin (Анатолий Шарифулин)',
-
-=head1 AUTHORS
+=head1 AUTHOR
 
 Zoffix Znet, C<< <'zoffix at cpan.org'> >>
 (L<http://zoffix.com/>, L<http://haslayout.net/>, L<http://zofdesign.com/>)
 
-Anatoly Sharifulin, E<lt>sharifulin at gmail.comE<gt>
+Anatoly Sharifulin, C<< <sharifulin at gmail.com> >>
 
 =head1 BUGS
 
@@ -230,7 +349,7 @@ L<http://search.cpan.org/dist/Acme-CPANAuthors-Russian>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2008 by Zoffix Znet.
+Copyright (C) 2008-2009 by Zoffix Znet.
 Copyright (C) 2009 by Anatoly Sharifulin.
 
 This program is free software; you can redistribute it and/or modify it
